====================
Weird Computer Games
====================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/open?id=0Bxv0SsvibDMTb2VxczM3WGNBLUE>`__



.. toctree::
   :maxdepth: 1

   tower_of_terror/index
   skulls_of_the_pyramid/index
   monster_wrestling/index
   jaws/index
   flying_witches/index
   micropuzzle/index

